package com.qiaoba.module.system.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qiaoba.api.system.entity.SysConfig;
import com.qiaoba.api.system.entity.param.SysConfigParam;
import com.qiaoba.common.database.entity.PageQuery;
import com.qiaoba.common.database.entity.TableDataInfo;
import com.qiaoba.module.system.mapper.SysConfigMapper;
import com.qiaoba.module.system.service.SysConfigService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 系统配置 服务层实现
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023-04-23 20:33:43
 */
@Service
@RequiredArgsConstructor
public class SysConfigServiceImpl implements SysConfigService {

    private final SysConfigMapper sysConfigMapper;

    @Override
    public int insert(SysConfig sysConfig) {
        return sysConfigMapper.insert(sysConfig);
    }

    @Override
    public int updateById(SysConfig sysConfig) {
        return sysConfigMapper.updateById(sysConfig);
    }

    @Override
    public List<SysConfig> selectList(SysConfigParam param) {
        return sysConfigMapper.selectList(param2Wrapper(param));
    }

    @Override
    public SysConfig selectById(String configId) {
        return sysConfigMapper.selectById(configId);
    }

    @Override
    public int deleteById(String configId) {
        return sysConfigMapper.deleteById(configId);
    }

    @Override
    public int deleteByIds(List<String> ids) {
        return sysConfigMapper.deleteBatchIds(ids);
    }

    @Override
    public void resetConfigCache() {

    }

    @Override
    public String selectConfigByKey(String configKey) {
        return null;
    }

    private QueryWrapper<SysConfig> param2Wrapper(SysConfigParam param) {
        QueryWrapper<SysConfig> wrapper = new QueryWrapper<>();
        wrapper.lambda()
                .like(StrUtil.isNotBlank(param.getConfigName()), SysConfig::getConfigName, param.getConfigName())
                .like(StrUtil.isNotBlank(param.getConfigKey()), SysConfig::getConfigKey, param.getConfigKey())
                .eq(StrUtil.isNotBlank(param.getConfigType()), SysConfig::getConfigType, param.getConfigType());
        return wrapper;
    }

    @Override
    public TableDataInfo<SysConfig> selectPageList(SysConfigParam param, PageQuery pageQuery) {
        return TableDataInfo.build(sysConfigMapper.selectPage(pageQuery.build(), param2Wrapper(param)));
    }
}
